@@ -26,7 +26,7 @@
 #include "e-cell.h"
 #include "gal/util/e-util.h"
 
-#define PARENT_TYPE gtk_object_get_type ()
+#define PARENT_TYPE GTK_TYPE_OBJECT
 
 #define ECVIEW_EC_CLASS(v) (E_CELL_GET_CLASS (v->ecell))
 
@@ -436,7 +436,7 @@ e_cell_max_width (ECellView *ecell_view, int model_col, int view_col)
 	return ECVIEW_EC_CLASS(ecell_view)->max_width 
 		(ecell_view, model_col, view_col);
 }
-	      
+
 /**
  * e_cell_max_width_by_row:
  * @ecell_view: the ECellView that we are curious about
@@ -496,3 +496,4 @@ e_cell_style_set(ECellView *ecell_view, GtkStyle *previous_style)
 	if (ECVIEW_EC_CLASS(ecell_view)->style_set)
 		ECVIEW_EC_CLASS(ecell_view)->style_set (ecell_view, previous_style);
 }
+		 		
